# cody.py (Explorer Workshop)
# Copyright: 2024 Bradan Lane STUDIO
#
# Open Source License: MIT

'''
This CircuitPython program is a sample from the 'Hack the Badge' workshop

Implementation Notes
--------------------
**Hardware:**
    * one of the Explorer Badge designs

**Software and Dependencies:**
    * CircuitPython firmware (UF2): https://circuitpython.org
    * Adafruit CircuitPython Libraries: https://circuitpython.org/libraries

**Open Source Repository:**
    * GitLab: https://gitlab.com/bradanlane/exp_tutorial
    
'''

import time
import board
import touchio

''' setup one capacitive touch sensor '''
touch_sensor = touchio.TouchIn(board.TOUCH1)
# the minimum sensitivity (aka threshold) is set when the touch sensor is created
print(f"initialized touch with threshold {touch_sensor.threshold:d}")

while True:
    # create a list to store the raw values
    raw_values = []

    while True:
        # add the current raw value to the list
        raw_values.append(touch_sensor.raw_value)
        
        # if the list has more than 10 values, remove the oldest value
        if len(raw_values) > 10:
            raw_values.pop(0)
        
        # calculate the rolling average
        rolling_average = sum(raw_values) // len(raw_values)
        
        # print the rolling average, touch threshold, and raw value
        print(f"{(500 if touch_sensor.value else 0)}, {touch_sensor.threshold}, {rolling_average}")
        
        time.sleep(0.05)
