# cody.py (Explorer Workshop)
# Copyright: 2024 Bradan Lane STUDIO
#
# Open Source License: MIT

'''
This CircuitPython program is a sample from the 'Hack the Badge' workshop

Implementation Notes
--------------------
**Hardware:**
    * one of the Explorer Badge designs

**Software and Dependencies:**
    * CircuitPython firmware (UF2): https://circuitpython.org
    * Adafruit CircuitPython Libraries: https://circuitpython.org/libraries

**Open Source Repository:**
    * GitLab: https://gitlab.com/bradanlane/exp_tutorial
    
'''

import board


# when using I2C, we need to lock the bus, before read/right tasks, and then unlock the bus
i2c_bus = board.I2C()
try:    # wrapping code is 'try:except' lets us catch errors which would otherwise halt our code
    if i2c_bus.try_lock():
        print("Scanning I2C bus: ", end="") # the 'end' lets us suspend the default newline
        count = 0
        for x in i2c_bus.scan():
            print(hex(x), end=" ")
            count += 1
        print("= {:d} device(s) found".format(count))
    i2c_bus.unlock()
except Exception as e:
    print("We failed to scan the I2C bus - ", e)

i2c_bus.unlock()
