# cody.py (Explorer Workshop)
# Copyright: 2024 Bradan Lane STUDIO
#
# Open Source License: MIT

'''
This CircuitPython program is a demo of the badge hardware

Implementation Notes
--------------------
**Hardware:**
    * one of the //BADGE_NAME// designs

**Software and Dependencies:**
    * CircuitPython firmware (UF2): https://circuitpython.org
    * Adafruit CircuitPython Libraries: https://circuitpython.org/libraries
'''


import board
import time
import random
from lib.explorer import expDisplay

def run_demo(text=None):
    if text is None:
        DISPLAY_MESSAGES = ["SETEC\nASTRONOMY", "YOUR\nNAME\nHERE", "DEFCON\nNEXTGEN", "DC32\nENGAGE", "PRIVACY\nNOT FOR\nSALE", "FIX\nTHE\nPLANET", "1%\nof\n1%", "EXPLORER\nBADGE"]
        text = DISPLAY_MESSAGES[random.randint(0, len(DISPLAY_MESSAGES)-1)]
    try:
        count = 0
        parts = text.split("\n")
        for part in parts:
            count = count if count >= len(part) else len(part)
        # chose largest usable font
        if board.VID() == 2:
            BASE_NAME = "neuropolx"
        else:
            BASE_NAME = "graffiti"

        font_size = 18
        if   count > 8: font_size = 6
        elif count > 6: font_size = 9
        elif count > 4: font_size = 12

        fullname = f"{BASE_NAME}{font_size:d}.bdf"
        
        expDisplay.enable()
        display = expDisplay()
        print("Display '{}' on a red background".format(text))
        display.background(expDisplay.RED)
        display.text(fullname, text, expDisplay.WHITE, bgcolor=None, x=expDisplay.WIDTH / 2, y=expDisplay.HEIGHT / 2)
        wait = display.refresh()
        print("Display refresh will take {:f} seconds ".format(wait))
        time.sleep(wait + 0.5)
        while display.busy:
            print("Display is busy")
            time.sleep(0.5)
        time.sleep(0.5) # time for the ePaper to settle
        display.disable()
        
        count = 0
        while True:
            time.sleep(1.0)
            count += 1
            print(count)
    finally:
        print("done")
    # end run_demo()


run_demo("Bradan\nLane")  # run the demo # this only gets executed if the program is not run as a module
